@@ -16,10 +16,13 @@
 import re
 import sys
 import blockdiag.elements
-from blockdiag.elements import NodeGroup, unquote
 from blockdiag.utils import images, Size, XY
 
 
+class NodeGroup(blockdiag.elements.NodeGroup):
+    pass
+
+
 class DiagramNode(blockdiag.elements.DiagramNode):
     def __init__(self, _id):
         super(DiagramNode, self).__init__(_id)
