@@ -5,9 +5,7 @@ import sys
 import re
 import tempfile
 import seqdiag.command
-from utils import *
-from seqdiag.elements import *
-from blockdiag.tests.utils import supported_pil
+from blockdiag.tests.utils import stderr_wrapper
 
 
 def extra_case(func):
@@ -23,9 +21,8 @@ def extra_case(func):
     return func
 
 
-@argv_wrapper
 @stderr_wrapper
-def __build_diagram(filename, format, args):
+def __build_diagram(filename, format, additional_args):
     testdir = os.path.dirname(__file__)
     diagpath = "%s/diagrams/%s" % (testdir, filename)
 
@@ -37,16 +34,16 @@ def __build_diagram(filename, format, args):
         tmpfile = tempfile.mkstemp(dir=tmpdir)
         os.close(tmpfile[0])
 
-        sys.argv = ['seqdiag.py', '-T', format, '-o', tmpfile[1], diagpath]
-        if args:
-            if isinstance(args[0], (list, tuple)):
-                sys.argv += args[0]
+        args = ['-T', format, '-o', tmpfile[1], diagpath]
+        if additional_args:
+            if isinstance(additional_args[0], (list, tuple)):
+                args += additional_args[0]
             else:
-                sys.argv += args
+                args += additional_args
         if os.path.exists(fontpath):
-            sys.argv += ['-f', fontpath]
+            args += ['-f', fontpath]
 
-        seqdiag.command.main()
+        seqdiag.command.main(args)
 
         if re.search('ERROR', sys.stderr.getvalue()):
             raise RuntimeError(sys.stderr.getvalue())
@@ -67,11 +64,7 @@ def diagram_files():
 
 
 def test_generator_svg():
-    args = []
-    if not supported_pil():
-        args.append('--ignore-pil')
-
-    for testcase in generator_core('svg', args):
+    for testcase in generator_core('svg'):
         yield testcase
 
 
